-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity


local addonName, addonTable = ...
local L = addonTable.L

local help = DailyGlobalCheck.HelpFunctions
help.buttons = {}
local help_frame
local current_helpplate
local news_cap = 0

-- this is a rough readaptation of the blizzard's tutorial frame, made to avoid taint issues
local function CreateHelpFrame()
 -- helpframe
 help.DGCHelpPlate = CreateFrame("Frame")
 help_frame = help.DGCHelpPlate
 help_frame:SetFrameStrata("HIGH")
 help_frame:EnableMouse(true)
end

local function hideplatetooltip()
 DGC_HelpPlateTooltip.ArrowUP:Hide()
 DGC_HelpPlateTooltip.ArrowGlowUP:Hide()
 DGC_HelpPlateTooltip.ArrowDOWN:Hide()
 DGC_HelpPlateTooltip.ArrowGlowDOWN:Hide()
 DGC_HelpPlateTooltip.ArrowLEFT:Hide()
 DGC_HelpPlateTooltip.ArrowGlowLEFT:Hide()
 DGC_HelpPlateTooltip.ArrowRIGHT:Hide()
 DGC_HelpPlateTooltip.ArrowGlowRIGHT:Hide()
 DGC_HelpPlateTooltip:ClearAllPoints()
 DGC_HelpPlateTooltip:Hide()
end

local function btn_onenter(self)
 hideplatetooltip()
 
 if ( self.tooltipDir == "UP" ) then
  DGC_HelpPlateTooltip.ArrowUP:Show()
  DGC_HelpPlateTooltip.ArrowGlowUP:Show()
  DGC_HelpPlateTooltip:SetPoint("BOTTOM", self, "TOP", 0, 10)
 elseif ( self.tooltipDir == "DOWN" ) then
  DGC_HelpPlateTooltip.ArrowDOWN:Show()
  DGC_HelpPlateTooltip.ArrowGlowDOWN:Show()
  DGC_HelpPlateTooltip:SetPoint("TOP", self, "BOTTOM", 0, -10)
 elseif ( self.tooltipDir == "LEFT" ) then
  DGC_HelpPlateTooltip.ArrowLEFT:Show()
  DGC_HelpPlateTooltip.ArrowGlowLEFT:Show()
  DGC_HelpPlateTooltip:SetPoint("RIGHT", self, "LEFT", -10, 0)
 elseif ( self.tooltipDir == "RIGHT" ) then
  DGC_HelpPlateTooltip.ArrowRIGHT:Show()
  DGC_HelpPlateTooltip.ArrowGlowRIGHT:Show()
  DGC_HelpPlateTooltip:SetPoint("LEFT", self, "RIGHT", 10, 0)
 end
 
 DGC_HelpPlateTooltip.Text:SetText(self.toolTipText)
 DGC_HelpPlateTooltip:Show()
 self.box:Hide()
 self.boxHighlight:Show()
 self.Pulse:Stop()
 self.BigI:Hide()
 self.Ring:Hide()
end

local function btn_onleave(self)
 hideplatetooltip()
 
 self.box:Show()
 self.boxHighlight:Hide()
 self.viewed = true
end

local function getButton()
 local f
 
 for i = 1, #help.buttons do
  local button = help.buttons[i]
   if not button:IsShown() then
	frame = button
	break
   end
 end
 
 if not f then
  f = CreateFrame("Button", nil, help_frame, "HelpPlateButton")
  f:SetFrameStrata("HIGH")
  f.box = CreateFrame("Frame", nil, help_frame, "HelpPlateBox")
  f.boxHighlight = CreateFrame("Frame", nil, help_frame, "HelpPlateBoxHighlight")
  f:SetScript("OnEnter", btn_onenter)
  f:SetScript("OnLeave", btn_onleave)
  table.insert(help.buttons, f)
 end
 
 f.tooltipDir = "RIGHT"
 f:SetSize(HELP_BUTTON_NORMAL_SIZE, HELP_BUTTON_NORMAL_SIZE)
 return f
end

function help:Show(plate, p, helpButton)
 if not help_frame then CreateHelpFrame() end
 
 if current_helpplate then help:Hide() end

 current_helpplate = plate
 current_helpplate.mainHelpButton = helpButton
 for i = 1, #current_helpplate do
  if ( not current_helpplate[i].MinLevel or (UnitLevel("player") >= current_helpplate[i].MinLevel) ) then
   local button = getButton()
   button:ClearAllPoints()
   button:SetPoint( "TOPLEFT", help_frame, "TOPLEFT", current_helpplate[i].ButtonPos.x, current_helpplate[i].ButtonPos.y )
   button.tooltipDir = current_helpplate[i].ToolTipDir
   button.toolTipText = current_helpplate[i].ToolTipText
   button.viewed = false
   button:Show()
   button.BigI:Hide()
   button.Ring:Hide()
   button.Pulse:Stop()
   button.box:ClearAllPoints()
   button.box:SetSize( current_helpplate[i].HighLightBox.width, current_helpplate[i].HighLightBox.height )
   button.box:SetPoint( "TOPLEFT", help_frame, "TOPLEFT", current_helpplate[i].HighLightBox.x, current_helpplate[i].HighLightBox.y )
   button.box:Show()
   button.boxHighlight:ClearAllPoints()
   button.boxHighlight:SetSize( current_helpplate[i].HighLightBox.width, current_helpplate[i].HighLightBox.height )
   button.boxHighlight:SetPoint( "TOPLEFT", help_frame, "TOPLEFT", current_helpplate[i].HighLightBox.x, current_helpplate[i].HighLightBox.y )
   button.boxHighlight:Hide()
  end
 end
 
 help_frame:SetScale(p:GetEffectiveScale())
 help_frame:SetPoint( "TOPLEFT", p, "TOPLEFT", plate.FramePos.x, plate.FramePos.y )
 help_frame:SetSize( plate.FrameSize.width, plate.FrameSize.height )
 help_frame:Show()
end

function help:Hide()
 if not help_frame then return end
 
 for i = 1, #help.buttons do
  local button = help.buttons[i]
  button.tooltipDir = "RIGHT"
  button.box:Hide()
  button:Hide()
 end
 current_helpplate = nil
 help_frame:Hide()
 return
end

function help:isShowing(helpplate)
 return current_helpplate == helpplate
end
--

local function hasNonReadNews()
 return (DailyGlobalCheck_Options["news_read"] or 0) < news_cap
end

local news_frame
local function news_next()
 local f = news_frame
 local increment = DGC_HelpPlateTooltip:IsVisible()

 if increment then
  if L["news_#"..(f.index + 1)] then
   f.index = f.index + 1
  else
   f.index = 1
  end
 end

 local svar = DailyGlobalCheck_Options["news_read"] or 0
 if f.index > svar then
  DailyGlobalCheck_Options["news_read"] = f.index
 end
 f.exclamation_point:Hide()
 hideplatetooltip()
 DGC_HelpPlateTooltip.ArrowUP:Show()
 DGC_HelpPlateTooltip.ArrowGlowUP:Show()
 DGC_HelpPlateTooltip:SetPoint("BOTTOM", f, "TOP", 0, 10)
 local news = L["news_#"..f.index]

 local s = "|cffffcc00"..GUILD_TAB_NEWS.."\n|cff11DDFF"..f.index.." / " ..news_cap..
           "|r\n"..news.."\n"..L["news_bottomtext1"].."\n"..L["news_bottomtext2"]
 DGC_HelpPlateTooltip.Text:SetText(s)
 DGC_HelpPlateTooltip:Show()
end

local function news_hide()
 hideplatetooltip()
 DGC_Mainframe.news_frame:SetAnimation(97)
 local visible = news_frame:IsVisible()
 if not visible or not hasNonReadNews() then
  news_frame.exclamation_point:Hide()
 elseif visible then
  news_frame.exclamation_point:Show()
 end
end

function help:CreateNewsFrame()
 local f = DGC_Mainframe
 f.news_frame = CreateFrame("DressUpModel", nil, f)
 f.news_frame:SetPoint("BOTTOMRIGHT", f, "TOPRIGHT", 0, -10)
 f.news_frame:SetSize(85,85)
 f.news_frame:SetDisplayInfo(53154) -- grommash
 --f.news_frame:SetDisplayInfo(38521) -- hallow's end crone
 f.news_frame:SetFrameStrata("MEDIUM")
 f.news_frame:SetScript("OnMouseUp", function(self, button)
  if button == "LeftButton" then
   --self:SetAnimation(69) -- dance
   --self:SetAnimation(60) -- chat
   --self:SetAnimation(113) -- salute
   self:SetAnimation(67) -- wave
   news_next()
  else
   f.news_frame:SetAnimation(97)
   news_hide()
  end
 end)
 f.news_frame:SetScript("OnHide", news_hide)
 
 f.news_frame:SetScript("OnShow", function(self)
  if hasNonReadNews() then
   self.exclamation_point:Show()
  end
 end)
 f.news_frame:SetAnimation(97)
 news_frame = f.news_frame
 
 f.news_frame.exclamation_point = f:CreateTexture()
 f.news_frame.exclamation_point:SetSize(35,35)
 f.news_frame.exclamation_point:SetPoint("BOTTOM", f.news_frame, "TOP", 0, -35)
 f.news_frame.exclamation_point:SetTexture("Interface\\Minimap\\ObjectIcons")
 f.news_frame.exclamation_point:SetTexCoord(0.125, 0.256, 0.125, 0.256)
 f.news_frame.exclamation_point:Hide()
 local ag = f.news_frame.exclamation_point:CreateAnimationGroup()    
 local a = ag:CreateAnimation("Scale")
 a:SetScale(0.75,0.75)
 a:SetDuration(1)
 ag:SetLooping("BOUNCE")
 ag:Play()
 
 local i = 1
 local t = L["news_#"..1]
 while t do
  i = i + 1
  t = L["news_#"..i]
 end
 news_cap = i - 1
 
 f.news_frame.index = math.min(DailyGlobalCheck_Options["news_read"] or 1, news_cap)

 f.news_frame:Show()
end
--